@@ -20,15 +20,23 @@
 
 int main(int argc, char **argv)
 {
- KApplication a(argc, argv);
- KPopup w(argc, argv);
- w.setGeometry(100, 100, 400, 400);
- a.setMainWidget(&w );
+ KApplication a(argc, argv, "kpopup");
  if(argc != 1)
    {
     a.beep();
    }
- w.setCaption("KPopup 0.3.1");
- w.show();
+// if (a.isRestored())
+//		RESTORE(Komba)
+//	else {
+ Kpopup *w = new Kpopup(argc, argv);
+ w -> setGeometry(100, 100, 400, 400);
+ w -> setCaption("Kpopup");
+ if(argc != 1)
+   {
+    a.beep();
+   }
+ a.setMainWidget(w);
+ w -> show();
+//	}
  return a.exec();
-}
\ No newline at end of file
+}
