@@ -45,7 +45,7 @@ char *File_read(const char *Filename, int ZLaenge)
 
     if(PopupText == NULL) PopupText = (char *) malloc (sizeof(char));
      else PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);
-    PopupText[i] = 0;
+    PopupText[i - 1] = 0;
     fclose(File);
 
     sprintf(Command, "rm -f %s", Filename);
