@@ -14,7 +14,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifndef MISC_H
+#define MISC_H
+
 //Path of smbclient
 #define SMBPATH "/usr/bin"
 
 char *File_read(const char *Filename, int ZLaenge);
+
+#endif
\ No newline at end of file
